OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Upotettu viesti %s",
    "Important mail" : "Tärkeä sähköposti",
    "No message found yet" : "Yhtäkään viestiä ei ole vielä löytynyt",
    "Set up an account" : "Määritä tili",
    "Unread mail" : "Lukematon sähköposti",
    "Important" : "Tärkeä",
    "Work" : "Työ",
    "Personal" : "Henkilökohtainen",
    "To Do" : "Tehtävä",
    "Later" : "Myöhemmin",
    "Mail" : "Sähköposti",
    "Mails" : "Sähköpostit",
    "💌 A mail app for Nextcloud" : "💌 Sähköpostisovellus Nextcloudille",
    "Your session has expired. The page will be reloaded." : "Istuntosi on vanhentunut. Sivu ladataan uudelleen.",
    "Drafts are saved in:" : "Luonnokset tallennetaan sijaintiin:",
    "Sent messages are saved in:" : "Lähetetyt viestit tallennetaan sijaintiin:",
    "Deleted messages are moved in:" : "Poistetut viestit tallennetaan sijaintiin:",
    "Archived messages are moved in:" : "Siirrä arkistoidut viestit:",
    "Auto" : "Automaattinen",
    "Name" : "Nimi",
    "Mail address" : "Sähköpostiosoite",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Kirjoita sähköpostiosoite muiodossa name@example.com",
    "Password" : "Salasana",
    "Manual" : "Manuaalinen",
    "IMAP Settings" : "IMAP-asetukset",
    "IMAP Host" : "IMAP-palvelin",
    "IMAP Security" : "IMAP-tietoturva",
    "None" : "Ei mitään",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-portti",
    "IMAP User" : "IMAP-käyttäjä",
    "IMAP Password" : "IMAP-salasana",
    "SMTP Settings" : "SMTP-asetukset",
    "SMTP Host" : "SMTP-palvelin",
    "SMTP Security" : "SMTP-tietoturva",
    "SMTP Port" : "SMTP-portti",
    "SMTP User" : "SMTP-käyttäjä",
    "SMTP Password" : "SMTP-salasana",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Google-tilin toiminta tämän sovelluksen kanssa vaatii, että otat kaksivaiheisen todennuksen käyttöön Googlessa ja luot sovelluksen salasanan.",
    "Connecting" : "Yhdistetään",
    "Reconnect Google account" : "Yhdistä Google-tili uudelleen",
    "Sign in with Google" : "Kirjaudu sisään Google-tililläsi",
    "Save" : "Tallenna",
    "Connect" : "Yhdistä",
    "Looking up configuration" : "Etsitään määrityksiä",
    "Password required" : "Salasana vaaditaan",
    "Testing authentication" : "Testataan tunnistautumista",
    "Awaiting user consent" : "Odotetaan käyttäjän hyväksyntää",
    "Loading account" : "Ladataan tiliä",
    "Account updated" : "Tili päivitetty",
    "IMAP server is not reachable" : "IMAP-palvelin ei ole tavoitettavissa",
    "SMTP server is not reachable" : "SMTP-palvelin ei ole tavoitettavissa",
    "IMAP username or password is wrong" : "IMAP-käyttäjätunnus tai -salasana on väärin",
    "SMTP username or password is wrong" : "SMTP-käyttäjätunnus tai -salasana on väärin",
    "IMAP connection failed" : "IMAP-yhteys epäonnistui",
    "SMTP connection failed" : "SMTP-yhteys epäonnistui",
    "Authorization pop-up closed" : "Valtuutusikkuna suljettu",
    "There was an error while setting up your account" : "Tiliä määrittäessä ilmeni virhe",
    "Account settings" : "Tilin asetukset",
    "Aliases" : "Aliakset",
    "Signature" : "Allekirjoitus",
    "A signature is added to the text of new messages and replies." : "Allekirjoitus lisätään uusien viestien ja vastausten tekstiosaan.",
    "Writing mode" : "Kirjoitustila",
    "Preferred writing mode for new messages and replies." : "Ensisijainen kirjoitustila uusissa viesteissä ja vastauksissa.",
    "Default folders" : "Oletuskansiot",
    "Autoresponder" : "Automaattivastaukset",
    "Sieve filter rules" : "Sieve-filtterin säännöt",
    "Mail server" : "Sähköpostipalvelin",
    "Sieve filter server" : "Sieve-filtteripalvelin",
    "Update alias" : "Päivitä alias",
    "Delete alias" : "Poista alias",
    "Go back" : "Takaisin",
    "Change name" : "Vaihda nimi",
    "Email address" : "Sähköpostiosoite",
    "Add alias" : "Lisää alias",
    "Create alias" : "Luo alias",
    "Cancel" : "Peruuta",
    "Mail settings" : "Sähköpostin asetukset",
    "Add mail account" : "Lisää sähköpostitili",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
    "Trusted senders" : "Luotetut lähettäjät",
    "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
    "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
    "Register" : "Rekisteröidy",
    "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
    "Sorting" : "Lajittelu",
    "Newest" : "Uusimmat",
    "Oldest" : "Vanhimmat",
    "Looking for a way to encrypt your emails?" : "Etsitkö tapaa salata sähköpostisi?",
    "Keyboard" : "Näppäimistö",
    "Compose new message" : "Uusi viesti",
    "Newer message" : "Uudempi",
    "Older message" : "Vanhempi viesti",
    "Toggle star" : "Lisää/poista tähti",
    "Toggle unread" : "Merkitse luetuksi/lukemattomaksi",
    "Archive" : "Arkisto",
    "Delete" : "Poista",
    "Search" : "Etsi",
    "Send" : "Lähetä",
    "Refresh" : "Päivitä",
    "Put my text to the bottom of a reply instead of on top of it." : "Aseta tekstini vastauksen alaosaan yläosan sijaan",
    "Automatically classify importance of new email" : "Merkitse sähköpostin tärkeys automaattisesti",
    "Could not update preference" : "Asetuksia ei voitu päivittää",
    "Update Certificate" : "Päivitä varmenne",
    "No certificate" : "Ei varmennetta",
    "Certificate updated" : "Varmenne päivitetty",
    "Could not update certificate" : "Varmennetta ei voitu päivittää",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Kelvollinen {expiryDate} asti",
    "From" : "Lähettäjä",
    "Select account" : "Valitse tili",
    "To" : "Vastaanottaja",
    "Select recipient" : "Valitse vastaanottaja",
    "Contact or email address …" : "Yhteystieto tai sähköpostiosoite…",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Aihe",
    "Subject …" : "Aihe…",
    "This message came from a noreply address so your reply will probably not be read." : "Tämä viesti saapui noreply-osoitteesta, joten vastaustasi ei luultavasti lueta.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Seuraavilla vastaanottajilla ei ole S/MIME-varmennetta: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Seuraavilla vastaanottajilla ei ole PGP-avainta: {recipients}.",
    "Write message …" : "Kirjoita viesti…",
    "Saving draft …" : "Tallennetaan luonnosta…",
    "Error saving draft" : "Virhe tallentaessa luonnosta",
    "Draft saved" : "Luonnos tallennettu",
    "Save draft" : "Tallenna luonnos",
    "Discard & close draft" : "Hylkää ja sulje luonnos",
    "Enable formatting" : "Käytä muotoilua",
    "Disable formatting" : "Poista muotoilu käytöstä",
    "Upload attachment" : "Lähetä liite",
    "Add attachment from Files" : "Lisää liitteitä tiedostosovelluksesta",
    "Send later" : "Lähetä myöhemmin",
    "Request a read receipt" : "Pyydä lukukuittaus",
    "Sign message with S/MIME" : "Allekirjoita viesti S/MIME:llä",
    "Encrypt message with S/MIME" : "Salaa viesti S/MIME:llä",
    "Encrypt message with Mailvelope" : "Salaa viesti Mailvelopella",
    "Send now" : "Lähetä nyt",
    "Tomorrow morning" : "Huomenna aamulla",
    "Tomorrow afternoon" : "Huomenna iltapäivällä",
    "Monday morning" : "Maanantaiaamuna",
    "Custom date and time" : "Omavalintainen päivä ja aika",
    "Enter a date" : "Kirjoita päiväys",
    "Encrypt with S/MIME and send later" : "Salaa S/MIME:llä ja lähetä myöhemmin",
    "Encrypt with S/MIME and send" : "Salaa S/MIME:llä ja lähetä",
    "Encrypt with Mailvelope and send later" : "Salaa Mailvelopella ja lähetä myöhemmin",
    "Encrypt with Mailvelope and send" : "Salaa Mailvelopella ja lähetä",
    "Message {id} could not be found" : "Viestiä {id} ei löytynyt",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Mikä tahansa aiempi muotoilu (esimerkiksi lihavointi, kursivointi, alleviivaus tai sisennetyt kuvat) poistetaan.",
    "Turn off formatting" : "Poista muotoilu käytöstä",
    "Turn off and remove formatting" : "Poista käytöstä ja poista muotoilu",
    "Keep formatting" : "Säilytä muotoilu",
    "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
    "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
    "Choose" : "Valitse",
    "_{count} attachment_::_{count} attachments_" : ["{count} liite","{count} liitettä"],
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Liite ylittää sallitun enimmäiskoon {size}. Jaa tiedosto linkin kautta.","Liitteet ylittävät sallitun enimmäiskoon {size}. Jaa tiedostot linkin kautta."],
    "Expand composer" : "Laajenna lähetysikkunaa",
    "Close composer" : "Sulje lähetysikkuna",
    "Untitled message" : "Nimetön viesti",
    "Confirm" : "Vahvista",
    "Plain text" : "Raakateksti",
    "Rich text" : "Rikas teksti",
    "No messages in this mailbox" : "Ei viestejä tässä postilaatikossa",
    "No messages" : "Ei viestejä",
    "Draft: " : "Luonnos: ",
    "Encrypted message" : "Salattu viesti",
    "This message is unread" : "Tämä viesti on lukematon",
    "Unfavorite" : "Poista suosikeista",
    "Favorite" : "Suosikki",
    "Unread" : "Lukematon",
    "Read" : "Lue",
    "Unimportant" : "Ei tärkeä",
    "Mark not spam" : "Merkitse ei roskapostiksi",
    "Mark as spam" : "Merkitse roskapostiksi",
    "Unselect" : "Poista valinta",
    "Select" : "Valitse",
    "Edit tags" : "Muokkaa tunnisteita",
    "Snooze" : "Torkuta",
    "Move thread" : "Siirrä ketju",
    "Archive thread" : "Arkistoi ketju",
    "Delete thread" : "Poista ketju",
    "More actions" : "Lisää toimintoja",
    "Back" : "Takaisin",
    "Set custom snooze" : "Aseta mukautettu torkutus",
    "Edit as new message" : "Muokkaa uutena viestinä",
    "Create event" : "Luo tapahtuma",
    "Create task" : "Luo tehtävä",
    "Download message" : "Lataa viesti",
    "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
    "No subject" : "Ei aihetta",
    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
    "Could not delete message" : "Ei voitu poistaa viestiä",
    "Could not archive message" : "Viestiä ei voitu arkistoida",
    "Forward" : "Lähetä edelleen",
    "Load more" : "Lataa lisää",
    "_Mark {number} unread_::_Mark {number} unread_" : ["Merkitse {number} lukemattomaksi","Merkitse {number} lukemattomaksi"],
    "_Mark {number} read_::_Mark {number} read_" : ["Merkitse {number} luetuksi","Merkitse {number} luetuksi"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Merkitse {number} tärkeäksi","Merkitse {number} tärkeäksi"],
    "_Delete {number} thread_::_Delete {number} threads_" : ["Poista {number} ketju","Poista {number} ketjua"],
    "Report this bug" : "Ilmoita viasta",
    "All day" : "Koko päivä",
    "Select calendar" : "Valitse kalenteri",
    "Description" : "Kuvaus",
    "Create" : "Luo",
    "Event created" : "Tapahtuma luotu",
    "Could not create event" : "Tapahtumaa ei voitu luoda",
    "You accepted this invitation" : "Hyväksyit tämän kutsun",
    "You tentatively accepted this invitation" : "Hyväksyit tämän kutsun alustavasti",
    "You declined this invitation" : "Kieltäydyit tästä kutsusta",
    "You already reacted to this invitation" : "Reagoit jo tähän kutsuun",
    "You have been invited to an event" : "Sinut on kutsuttu tapahtumaan",
    "This event was cancelled" : "Tämä tapahtuma peruttiin",
    "Comment" : "Kommentti",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Tentatively accept" : "Alustavasti hyväksytty",
    "More options" : "Lisää valintoja",
    "This event is in the past." : "Tämä tapahtuma on menneisyydessä.",
    "This event was updated" : "Tämä tapahtuma päivitettiin",
    "{attendeeName} accepted your invitation" : "{attendeeName} hyväksyi kutsusi",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} hyväksyi kutsusi alustavasti",
    "{attendeeName} declined your invitation" : "{attendeeName} kieltäytyi kutsustasi",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reagoi kutsuusi",
    "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
    "Loading messages …" : "Ladataan viestejä …",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
    "Important info" : "Tärkeää tietoa",
    "Other" : "Muu",
    "The sender of this message has asked to be notified when you read this message." : "Tämän viestin lähettäjä on pyytänyt ilmoitusta, kun luet tämän viestin.",
    "Notify the sender" : "Ilmoita lähettäjälle",
    "You sent a read confirmation to the sender of this message." : "Lähetit lukukuittauksen tämän viestin lähettäjälle.",
    "Reply all" : "Vastaa kaikille",
    "Reply" : "Vastaa",
    "Reply to sender only" : "Vastaa vain lähettäjälle",
    "Move message" : "Siirrä viesti",
    "Forward message as attachment" : "Välitä viesti liitteenä",
    "View source" : "Näytä lähde",
    "Download thread data for debugging" : "Lataa ketjun data vianjäljitystä varten",
    "Message body" : "Viestin runko",
    "Import into calendar" : "Tuo kalenteriin",
    "Download attachment" : "Lataa liite",
    "Save to Files" : "Tallenna tiedostoihin",
    "Unnamed" : "Nimetön",
    "Embedded message" : "Upotettu viesti",
    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
    "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
    "View fewer attachments" : "Näytä vähemmän liitteitä",
    "Save all to Files" : "Tallenna kaikki tiedostoihin",
    "Download Zip" : "Lataa Zip",
    "Choose a folder to store the attachments in" : "Valitse kansio johon liitteet tallennetaan",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Näytä {count} liite lisää","Näytä {count} liitettä lisää"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Tämä viesti on salattu PGP:llä. Asenna Mailvelope purkaaksesi viestin salauksen.",
    "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
    "Show images" : "Näytä kuvat",
    "Show images temporarily" : "Näytä kuvat väliaikaisesti",
    "Always show images from {sender}" : "Näytä aina kuvat lähettäjältä {sender}",
    "Always show images from {domain}" : "Näytä aina kuvat verkkotunnuksesta {domain}",
    "Message frame" : "Viestiruutu",
    "Quoted text" : "Lainattu teksti",
    "Move" : "Siirrä",
    "Moving" : "Siirretään",
    "Moving thread" : "Siirretään ketjua",
    "Moving message" : "Siirretään viestiä",
    "Quota" : "Kiintiö",
    "Show only subscribed mailboxes" : "Näytä vain tilatut postilaatikot",
    "Add mailbox" : "Lisää postilaatikko",
    "Saving" : "Tallennetaan",
    "Move up" : "Siirrä ylös",
    "Move down" : "Siirrä alas",
    "Remove account" : "Poista tili",
    "Loading …" : "Ladataan…",
    "Not supported by the server" : "Ei tuettu palvelimen toimesta",
    "{usage} of {limit} used" : "{usage}/{limit} käytetty",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tili {email} ja tallennetut viesti poistetaan Nextcloudista, muttei sähköpostintarjoajaltasi.",
    "Remove account {email}" : "Poista tili {email}",
    "Remove {email}" : "Poista {email}",
    "Show all subscribed mailboxes" : "Näytä kaikki tilatut postilaatikot",
    "Show all mailboxes" : "Näytä kaikki postilaatikot",
    "Collapse mailboxes" : "Supista postilaatikot",
    "Mark all as read" : "Merkitse kaikki luetuiksi",
    "Mark all messages of this mailbox as read" : "Merkitse kaikki tämän postilaatikon viestit luetuiksi",
    "Add submailbox" : "Lisää alipostilaatikko",
    "Edit name" : "Muokkaa nimeä",
    "Clear cache" : "Tyhjennä välimuisti",
    "Clear locally cached data, in case there are issues with synchronization." : "Poista paikallisesti tallennetut tiedot, jos synkronoinnissa on ongelmia.",
    "Subscribed" : "Tilattu",
    "Sync in background" : "Synkronoi taustalla",
    "Clear mailbox" : "Tyhjennä postilaatikko",
    "Delete mailbox" : "Poista postilaatikko",
    "All messages in mailbox will be deleted." : "Kaikki postilaatikon viestit poistetaan.",
    "Clear mailbox {name}" : "Tyhjennä postilaatikko {name}",
    "The mailbox and all messages in it will be deleted." : "Tämä postilaatikko ja kaikki sen viestit poistetaan.",
    "Delete mailbox {name}" : "Poista postilaatikko {name}",
    "An error occurred, unable to rename the mailbox." : "Tapahtui virhe. Postilaatikon nimeäminen uudelleen ei onnistunut.",
    "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
    "New message" : "Uusi viesti",
    "Error sending your message" : "Virhe viestiäsi lähettäessä",
    "Retry" : "Yritä uudelleen",
    "Uploading attachments …" : "Lähetetään liitteitä…",
    "Sending …" : "Lähetetään…",
    "Warning sending your message" : "Varoitus viestiä lähettäessä",
    "Send anyway" : "Lähetä silti",
    "Minimize composer" : "Pienennä lähetysikkuna",
    "Edit message" : "Muokkaa viestiä",
    "Draft" : "Luonnos",
    "Message saved" : "Viesti tallennettu",
    "Failed to save message" : "Viestin tallentaminen epäonnistui",
    "Failed to save draft" : "Luonnoksen tallentaminen epäonnistui",
    "No sent mailbox configured. Please pick one in the account settings." : "Ei postilaatikkoa lähetetyille määritetty. Valitse se tilin asetuksista.",
    "Message discarded" : "Viesti hylätty",
    "Could not discard message" : "Viestiä ei voitu hylätä",
    "Autoresponder off" : "Automaattivastaukset pois päältä",
    "Autoresponder on" : "Automaattivastaukset päällä",
    "First day" : "Ensimmäinen päivä",
    "Last day (optional)" : "Viimeinen päivä (valinnainen)",
    "Message" : "Viesti",
    "Oh Snap!" : "Oho!",
    "Save autoresponder" : "Tallenna automaattivastaus",
    "Pending or not sent messages will show up here" : "Odottavat tai vielä lähettämättömät viestit näkyvät täällä",
    "Message could not be sent" : "Viestiä ei voitu lähettää",
    "Message deleted" : "Viesti poistettu",
    "Contacts with this address" : "Yhteystiedot tällä osoitteella",
    "Add to Contact" : "Lisää yhteystietoon",
    "New Contact" : "Uusi yhteystieto",
    "Copy to clipboard" : "Kopioi leikepöydälle",
    "Contact name …" : "Yhteystiedon nimi…",
    "Add" : "Lisää",
    "Copied email address to clipboard" : "Sähköpostiosoite kopioitu leikepöydälle",
    "Could not copy email address to clipboard" : "Sähköpostiosoitetta ei voitu kopioida leikepöydälle",
    "Close" : "Sulje",
    "Body" : "Sisältö",
    "Pick a start date" : "Valitse aloituspäivä",
    "Pick an end date" : "Valitse päättymispäivä",
    "Tags" : "Tunnisteet",
    "Select tags" : "Valitse tunnisteet",
    "Has attachments" : "On liitteitä",
    "Clear" : "Tyhjennä",
    "Date" : "Päivä",
    "Disabled" : "Pois käytöstä",
    "Enabled" : "Käytössä",
    "Sieve Host" : "Sieve-palvelin",
    "Sieve Security" : "Sieve-tietoturva",
    "Sieve Port" : "Sieve-portti",
    "Sieve Credentials" : "Sieve-kirjautumistiedot",
    "IMAP Credentials" : "IMAP-kirjautumistiedot",
    "Custom" : "Omavalintainen",
    "Sieve User" : "Sieve-käyttäjä",
    "Sieve Password" : "Sieve-salasana",
    "Save sieve settings" : "Tallenna sieve-asetukset",
    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
    "Signature …" : "Allekirjoitus…",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
    "Save signature" : "Tallenna allekirjoitus",
    "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
    "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
    "Delete tag" : "Poista tunniste",
    "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
    "Add default tags" : "Lisää oletustunnisteet",
    "Add tag" : "Lisää tunniste",
    "Saving tag …" : "Tallennetaan tunnistetta…",
    "Tag name is a hidden system tag" : "Tunnisteen nimi on piilotettu järjestelmätunniste",
    "Tag already exists" : "Tunniste on jo olemassa",
    "An error occurred, unable to create the tag." : "Tapahtui virhe, tunnistetta ei voitu luoda.",
    "Task created" : "Tehtävä luotu",
    "Loading thread" : "Ladataan ketjua",
    "Not found" : "Ei löytynyt",
    "Could not load your message thread" : "Viestiketjua ei voitu ladata",
    "The thread doesn't exist or has been deleted" : "Ketjua ei ole olemassa tai se on poistettu",
    "Unsubscribe" : "Peruuta tilaus",
    "Mark as favorite" : "Merkitse suosikiksi",
    "Mark as unread" : "Merkitse lukemattomaksi",
    "Mark as read" : "Merkitse luetuksi",
    "Archive message" : "Arkistoi viesti",
    "Delete message" : "Poista viesti",
    "Message source" : "Viestin lähde",
    "Encrypted & verified " : "Salattu ja vahvistettu",
    "Signature verified" : "Allekirjoitus vahvistettu",
    "Signature unverified " : "Allekirjoitus vahvistamatta",
    "This message was encrypted by the sender before it was sent." : "Tämän viestin lähettäjä salasi viestin ennen sen lähettämistä.",
    "Remove" : "Poista",
    "No senders are trusted at the moment." : "Ei luotettuja lähettäjiä tällä hetkellä.",
    "Could not remove trusted sender {sender}" : "Ei voitu poistaa luotettua lähettäjää {sender}",
    "individual" : "yksittäinen",
    "domain" : "domaini",
    "(organizer)" : "(järjestäjä)",
    "Untitled event" : "Nimetön tapahtuma",
    "Import into {calendar}" : "Tuo kalenteriin {calendar}",
    "Event imported into {calendar}" : "Tapahtuma tuotiin kalenteriin {calendar}",
    "Airplane" : "Lentokone",
    "Reservation {id}" : "Varaus {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lento {flightNr} lentokentältä {depAirport} lentokentälle {arrAirport}",
    "Train" : "Juna",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} asemalta {depStation} asemalle {arrStation}",
    "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
    "Mail app" : "Sähköpostisovellus",
    "The mail app allows users to read mails on their IMAP accounts." : "Tämä sähköpostisovellus mahdollistaa käyttäjien lukea sähköpostiviestejä IMAP-tileiltä.",
    "Account provisioning" : "Käyttäjän provisiointi",
    "Provisioning Configurations" : "Provisiointi-asetukset",
    "Add new config" : "Lisää uusi asetus",
    "Provision all accounts" : "Provisioidaan kaikki käyttäjät",
    "Anti Spam Service" : "Roskapostin estopalvelu",
    "Gmail integration" : "Gmail-integraatio",
    "Microsoft integration" : "Microsoft-integraatio",
    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft sallii käyttäjien yhdistää sähköpostiin IMAP:ia käyttäen. Tietoturvasyistä tällainen käyttö on mahdollista vain OAuth 2.0 -yhteydellä.",
    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Rekisteröi uusi sovellus Microsoft Azure Active Directory -portaalissa. Lisää URL-osoite {url} uudelleenohjauksen URI:ksi.",
    "Anti Spam" : "Roskapostin esto",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Alkuperäinen viesti asetetaan \"message/rfc822\"-liitteeksi.",
    "Reset" : "Palauta",
    "Client ID" : "Asiakas-ID",
    "Client secret" : "Asiakassalasana",
    "Unlink" : "Poista linkitys",
    "Google integration configured" : "Google-integraatio määritetty",
    "Could not configure Google integration" : "Google-integraatiota ei voitu määrittää",
    "Google integration unlinked" : "Google-integraation linkitys poistettu",
    "Microsoft integration configured" : "Microsoft-integraatio määritetty",
    "Could not configure Microsoft integration" : "Microsoft-integraatiota ei voitu määrittää",
    "Email: {email}" : "Sähköposti: {email}",
    "General" : "Yleiset",
    "IMAP" : "IMAP",
    "User" : "Käyttäjä",
    "Host" : "Palvelin",
    "Port" : "Portti",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "LDAP aliases integration" : "LDAP-aliasten integraatio",
    "Enable LDAP aliases integration" : "Käytä LDAP-aliasten integraatiota",
    "Save Config" : "Tallenna asetus",
    "With the settings above, the app will create account settings in the following way:" : "Sovellus luo tiliasetukset yllä olevin asetuksin seuraavasti:",
    "S/MIME certificates" : "S/MIME-varmenteet",
    "Certificate name" : "Varmenteen nimi",
    "E-mail address" : "Sähköpostiosoite",
    "Valid until" : "Kelvollinen",
    "Delete certificate" : "Poista varmenne",
    "No certificate imported yet" : "Varmennetta ei ole vielä tuotu",
    "Import certificate" : "Tuo varmenne",
    "Import S/MIME certificate" : "Tuo S/MIME-varmenne",
    "PKCS #12 Certificate" : "PKCS #12 -varmenne",
    "PEM Certificate" : "PEM-varmenne",
    "Certificate" : "Varmenne",
    "Private key (optional)" : "Yksityinen avain (valinnainen)",
    "Submit" : "Lähetä",
    "Certificate imported successfully" : "Varmenne tuotu onnistuneesti",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Varmenteen tuonti epäonnistui. Varmista, että yksityinen avain vastaa varmennetta ja ettei se ole suojattu tunnuslauseella.",
    "Failed to import the certificate" : "Varmenteen tuominen epäonnistui",
    "Account connected" : "Tili yhdistetty",
    "You can close this window" : "Voit sulkea tämän ikkunan",
    "Connect your mail account" : "Yhdistä sähköpostitilisi",
    "To add a mail account, please contact your administrator." : "Ole yhteydessä ylläpitoon lisätäksesi sähköpostitilin.",
    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
    "All" : "Kaikki",
    "Drafts" : "Luonnokset",
    "Favorites" : "Suosikit",
    "Priority inbox" : "Tärkeät saapuneet",
    "All inboxes" : "Kaikki saapuneiden laatikot",
    "Inbox" : "Saapuneet",
    "Junk" : "Roskaposti",
    "Sent" : "Lähetetyt",
    "Trash" : "Roskakori",
    "Connect OAUTH2 account" : "Yhdistä OAUTH2-tili",
    "Error while sharing file" : "Virhe tiedostoa jakaessa",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n uusi viesti \nlähettäjältä {from}","%n uutta viestiä \nlähettäjältä {from}"],
    "Nextcloud Mail" : "Nextcloud-sähköposti",
    "Discard changes" : "Hylkää muutokset",
    "Discard unsaved changes" : "Hylkää tallentamattomat muutokset",
    "Keep editing message" : "Jatka viestin muokkausta",
    "Attachments were not copied. Please add them manually." : "Liitetiedostoja ei kopiotu. Lisää ne manuaalisesti.",
    "Message sent" : "Viesti lähetetty",
    "Could not send message" : "Viestiä ei voitu lähettää",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ei voitu ladata",
    "There was a problem loading {tag}{name}{endtag}" : "Ladattaessa {tag}{name}{endtag} ilmeni ongelma",
    "Could not load your message" : "Viestiä ei voitu ladata",
    "Could not load the desired message" : "Haluttua viestiä ei voitu ladata",
    "Could not load the message" : "Viestiä ei voitu ladata",
    "Error loading message" : "Virhe viestiä ladatessa",
    "Forwarding to %s" : "Välitä viesti %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
    "Redirect" : "Uudelleenohjaus",
    "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
    "Continue to %s" : "Jatka sivulle %s"
},
"nplurals=2; plural=(n != 1);");
